==> webapps-applications_2.4.6.orig.tar.gz: webapps-2.4.6/src/LinkedIn/LinkedIn.user.js <==
// ==UserScript==
// @include       http://www.linkedin.com/*
// @include       http://www.linkedin.com
// @require       utils.js
// ==/UserScript==

window.Unity = external.getUnityObject(1);

function isCorrectPage() {
    var i, ids = ['header', 'nav-primary-news'];

    for (i = 0; i < ids.length; i++) {
        if (!document.getElementById(ids[i])) {
            return false;
        }
    }

    return true;
}

function doMatrixIntegration() {
    function integrateSubMenu(parent) {
        var i, snapshot = document.evaluate('ul/li/a',
                                            parent, null, XPathResult.UNORDERED_NODE_SNAPSHOT_TYPE, null);
        for (i = 0; i < snapshot.snapshotLength; i++) {
            var node = snapshot.snapshotItem(i);
            var text = node.textContent;
            var link = node.href;
            console.log(text);
            Unity.addAction('/' + text, makeRedirector(link));
        }
    }
    var i, snapshot = document.evaluate('//div[@id="header"]/div[2]/div/ul/li',
                                        document, null, XPathResult.UNORDERED_NODE_SNAPSHOT_TYPE, null);

    for (i = 0; i < snapshot.snapshotLength; i++) {
        var node = snapshot.snapshotItem(i);
        var text = node.getElementsByTagName('a')[0].getElementsByTagName('span')[0].textContent;
        var link = node.getElementsByTagName('a')[0].href;

        console.log(text);
        Unity.addAction('/' + text, makeRedirector(link));
        integrateSubMenu(node);
    }
}

function messagingIndicatorSetup() {
    setInterval(wrapCallback(function () {
        var count = document.getElementById('nav-primary-inbox-item-total');

        if (count) {
            count = count.textContent.match(/\d+/)[0];
            Unity.MessagingIndicator.showIndicator(_("Inbox"), { count: count,
                                                                 callback: makeRedirector('http://www.linkedin.com/inbox/messages/received?trk=hb_tab_inbox_top') });
        }
    }), 4000);

    function composeNewMessage() {
        var node = document.evaluate('//div[@id="inbox-overlay-messages-header"]/div[2]/a',
                          document, null, XPathResult.ANY_UNORDERED_NODE_TYPE, null).singleNodeValue;
        launchClickEvent(node);
    }
    Unity.Launcher.addAction(_("Compose New Message"),
			     wrapCallback(composeNewMessage));

    doMatrixIntegration();
}

if (isCorrectPage()) {
    Unity.init({ name: 'LinkedIn',
		 domain: 'linkedin.com',
		 homepage: 'http://www.linkedin.com',
                 iconUrl: 'icon://linkedin',
                 onInit: wrapCallback(messagingIndicatorSetup) });
}

==> webapps-applications_2.4.7.orig.tar.gz: webapps-2.4.7/src/LinkedIn/LinkedIn.user.js <==
// ==UserScript==
// @include       http://www.linkedin.com/*
// @include       http://www.linkedin.com
// @require       utils.js
// ==/UserScript==

window.Unity = external.getUnityObject(1);

function isCorrectPage() {
    var i, ids = ['header', 'nav-primary-news'];

    for (i = 0; i < ids.length; i++) {
        if (!document.getElementById(ids[i])) {
            return false;
        }
    }

    return true;
}

function doMatrixIntegration() {
    function integrateSubMenu(parent) {
        var i, snapshot = document.evaluate('ul/li/a',
                                            parent, null, XPathResult.UNORDERED_NODE_SNAPSHOT_TYPE, null);
        for (i = 0; i < snapshot.snapshotLength; i++) {
            var node = snapshot.snapshotItem(i);
            var text = node.textContent;
            var link = node.href;
            console.log(text);
            Unity.addAction('/' + text, makeRedirector(link));
        }
    }
    var i, snapshot = document.evaluate('//div[@id="header"]/div[2]/div/ul/li',
                                        document, null, XPathResult.UNORDERED_NODE_SNAPSHOT_TYPE, null);

    for (i = 0; i < snapshot.snapshotLength; i++) {
        var node = snapshot.snapshotItem(i);
        var text = node.getElementsByTagName('a')[0].getElementsByTagName('span')[0].textContent;
        var link = node.getElementsByTagName('a')[0].href;

        console.log(text);
        Unity.addAction('/' + text, makeRedirector(link));
        integrateSubMenu(node);
    }
}

function messagingIndicatorSetup() {
    setInterval(wrapCallback(function () {
        var count = document.getElementById('header-messages-count');

        if (count) {
            count = count.textContent.match(/\d+/)[0];
            Unity.MessagingIndicator.showIndicator(_("Inbox"), { count: count,
                                                                 callback: makeRedirector('http://www.linkedin.com/inbox/messages/received?trk=hb_tab_inbox_top') });
        } else {
            Unity.MessagingIndicator.showIndicator(_("Inbox"), { count: 0,
                                                                 callback: makeRedirector('http://www.linkedin.com/inbox/messages/received?trk=hb_tab_inbox_top') });
        }
    }), 4000);

    function composeNewMessage() {
        var node = document.evaluate('//div[@id="inbox-overlay-messages-header"]/div[2]/a',
                          document, null, XPathResult.ANY_UNORDERED_NODE_TYPE, null).singleNodeValue;
        launchClickEvent(node);
    }
    Unity.Launcher.addAction(_("Compose New Message"),
			     wrapCallback(composeNewMessage));

    doMatrixIntegration();
}

if (isCorrectPage()) {
    Unity.init({ name: 'LinkedIn',
		 domain: 'linkedin.com',
		 homepage: 'http://www.linkedin.com',
                 iconUrl: 'icon://unity-webapps-linkedin',
                 onInit: wrapCallback(messagingIndicatorSetup) });
}
